@@ -21,7 +21,6 @@ from .functions_projects import (
     )
 from .functions import (
     load_file,
-    get_running_backend_version,
     )
 from .functions_components import (
     get_tags_from_string,
@@ -34,6 +33,8 @@ from .functions_components import (
 
 from .streamlit_functions import (
     show_mermaid_diagram,
+    st_show_backend_version,
+    st_project_selector,
 )
 
 # deprecated functions
