@@ -7,7 +7,7 @@ import toml
 import pandas as pd
 import warnings
 
-from ._backend_calls import _backend_POST, _backend_PUT, _backend_GET
+from .logging_setup import logger_ai4cehelper
 
 
 def load_file(filename: Path) -> dict | pd.DataFrame:
@@ -34,6 +34,7 @@ def load_file(filename: Path) -> dict | pd.DataFrame:
             return toml.load(file)
 
     else:
+        logger_ai4cehelper.error("(lf) Unsupported file format: " + filename.suffix)
         raise ValueError(
             "You need to add the file format to the load_file function.")
 
@@ -58,7 +59,7 @@ def move_parameter_placeholder(component: dict) -> dict:
         elif isinstance(value, list):
             component[key].extend(value)
         else:
-            warnings.warn(f"Found conflicting value for key '{key}': {component[key]} vs {value}")
+            logger_ai4cehelper.warning(f"(mpp) Found conflicting value for key '{key}': {component[key]} vs {value}")
     return component
 
 def cleanup_parameters(component: dict) -> dict:
@@ -76,14 +77,3 @@ def cleanup_parameters(component: dict) -> dict:
             # del component[key]
     return component
 
-def get_running_backend_version() -> str:
-    """Get the latest version of the backend from the openapi.json file.
-    """
-    status_code, response = _backend_GET("/openapi.json")
-    if status_code == 200 and isinstance(response, dict) and "info" in response and "version" in response["info"]:
-        # append "preview" if the version contains letters
-        version = response["info"]["version"]
-        if any(c.isalpha() for c in version):
-            version += " (preview)"
-        return version
-    return "unknown"
