@@ -48,6 +48,18 @@ def get_comp_statistics() -> dict:
     return response
 
 
+def get_comp_statistics_all_systems() -> dict:
+    """
+    Retrieves component statistics for all systems.
+
+    Returns:
+        dict: Statistics data for all systems, as retrieved from the backend.
+    """
+
+    status_code, response = _backend_GET(endpoint="/v2/streamlit/db/stats")
+    return response
+
+
 def split_uid(uid: str) -> tuple[str, str, str, int | str]:
     """Splits a component UID into its constituent parts: type, subtype, and name.
 
